/*
 * Copyright (C) 2023 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package android.health.connect.datatypes;


/**
 * Captures an occurrence of sexual activity. Each record is a single occurrence. ProtectionUsed
 * field is optional.
 */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public final class SexualActivityRecord extends android.health.connect.datatypes.InstantRecord {

SexualActivityRecord() { throw new RuntimeException("Stub!"); }

/**
 * @return protectionUsed

 * Value is {@link android.health.connect.datatypes.SexualActivityRecord.SexualActivityProtectionUsed#PROTECTION_USED_UNKNOWN}, {@link android.health.connect.datatypes.SexualActivityRecord.SexualActivityProtectionUsed#PROTECTION_USED_PROTECTED}, or {@link android.health.connect.datatypes.SexualActivityRecord.SexualActivityProtectionUsed#PROTECTION_USED_UNPROTECTED}
 */

public int getProtectionUsed() { throw new RuntimeException("Stub!"); }

/**
 * Indicates whether some other object is "equal to" this one.
 *
 * @param o the reference object with which to compare.
 * @return {@code true} if this object is the same as the obj
 */

public boolean equals(java.lang.Object o) { throw new RuntimeException("Stub!"); }

/** Returns a hash code value for the object. */

public int hashCode() { throw new RuntimeException("Stub!"); }
/** Builder class for {@link android.health.connect.datatypes.SexualActivityRecord SexualActivityRecord} */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public static final class Builder {

/**
 * @param metadata Metadata to be associated with the record. See {@link android.health.connect.datatypes.Metadata Metadata}.
 * This value cannot be {@code null}.
 * @param time Start time of this activity
 * This value cannot be {@code null}.
 * @param protectionUsed Whether protection was used during sexual activity. Optional field,
 *     null if unknown. Allowed values: Protection.

 * Value is {@link android.health.connect.datatypes.SexualActivityRecord.SexualActivityProtectionUsed#PROTECTION_USED_UNKNOWN}, {@link android.health.connect.datatypes.SexualActivityRecord.SexualActivityProtectionUsed#PROTECTION_USED_PROTECTED}, or {@link android.health.connect.datatypes.SexualActivityRecord.SexualActivityProtectionUsed#PROTECTION_USED_UNPROTECTED}
 */

public Builder(@android.annotation.NonNull android.health.connect.datatypes.Metadata metadata, @android.annotation.NonNull java.time.Instant time, int protectionUsed) { throw new RuntimeException("Stub!"); }

/**
 * Sets the zone offset of the user when the activity happened
 * @param zoneOffset This value cannot be {@code null}.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.health.connect.datatypes.SexualActivityRecord.Builder setZoneOffset(@android.annotation.NonNull java.time.ZoneOffset zoneOffset) { throw new RuntimeException("Stub!"); }

/**
 * Sets the zone offset of this record to system default.
 * @return This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.health.connect.datatypes.SexualActivityRecord.Builder clearZoneOffset() { throw new RuntimeException("Stub!"); }

/**
 * @return Object of {@link android.health.connect.datatypes.SexualActivityRecord SexualActivityRecord}

 * This value cannot be {@code null}.
 */

@android.annotation.NonNull
public android.health.connect.datatypes.SexualActivityRecord build() { throw new RuntimeException("Stub!"); }
}

/** Identifier for sexual activity protection used */

@SuppressWarnings({"unchecked", "deprecation", "all"})
public static final class SexualActivityProtectionUsed {

SexualActivityProtectionUsed() { throw new RuntimeException("Stub!"); }

public static final int PROTECTION_USED_PROTECTED = 1; // 0x1

public static final int PROTECTION_USED_UNKNOWN = 0; // 0x0

public static final int PROTECTION_USED_UNPROTECTED = 2; // 0x2
}

}

